@@ -17,14 +17,35 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#include <config.h>
 #include <string.h>
+#include <libintl.h>
+
+#include "eggtraymanager.h"
+
+#include <gdkconfig.h>
+#if defined (GDK_WINDOWING_X11)
 #include <gdk/gdkx.h>
+#include <X11/Xatom.h>
+#elif defined (GDK_WINDOWING_WIN32)
+#include <gdk/gdkwin32.h>
+#endif
 #include <gtk/gtkinvisible.h>
 #include <gtk/gtksocket.h>
 #include <gtk/gtkwindow.h>
-#include "eggtraymanager.h"
+
 #include "eggmarshalers.h"
 
+#ifndef EGG_COMPILATION
+#ifndef _
+#define _(x) dgettext (GETTEXT_PACKAGE, x)
+#define N_(x) x
+#endif
+#else
+#define _(x) x
+#define N_(x) x
+#endif
+
 /* Signals */
 enum
 {
@@ -36,14 +57,21 @@ enum
   LAST_SIGNAL
 };
 
+enum {
+  PROP_0,
+  PROP_ORIENTATION
+};
+
 typedef struct
 {
   long id, len;
   long remaining_len;
   
   long timeout;
-  Window window;
   char *str;
+#ifdef GDK_WINDOWING_X11
+  Window window;
+#endif
 } PendingMessage;
 
 static GObjectClass *parent_class = NULL;
@@ -53,12 +81,25 @@ static guint manager_signals[LAST_SIGNAL] = { 0 };
 #define SYSTEM_TRAY_BEGIN_MESSAGE   1
 #define SYSTEM_TRAY_CANCEL_MESSAGE  2
 
+#define SYSTEM_TRAY_ORIENTATION_HORZ 0
+#define SYSTEM_TRAY_ORIENTATION_VERT 1
+
+#ifdef GDK_WINDOWING_X11
 static gboolean egg_tray_manager_check_running_xscreen (Screen *xscreen);
+#endif
 
 static void egg_tray_manager_init (EggTrayManager *manager);
 static void egg_tray_manager_class_init (EggTrayManagerClass *klass);
 
-static void egg_tray_manager_finalize (GObject *object);
+static void egg_tray_manager_finalize     (GObject      *object);
+static void egg_tray_manager_set_property (GObject      *object,
+					   guint         prop_id,
+					   const GValue *value,
+					   GParamSpec   *pspec);
+static void egg_tray_manager_get_property (GObject      *object,
+					   guint         prop_id,
+					   GValue       *value,
+					   GParamSpec   *pspec);
 
 static void egg_tray_manager_unmanage (EggTrayManager *manager);
 
@@ -104,6 +145,17 @@ egg_tray_manager_class_init (EggTrayManagerClass *klass)
   gobject_class = (GObjectClass *)klass;
 
   gobject_class->finalize = egg_tray_manager_finalize;
+  gobject_class->set_property = egg_tray_manager_set_property;
+  gobject_class->get_property = egg_tray_manager_get_property;
+
+  g_object_class_install_property (gobject_class,
+				   PROP_ORIENTATION,
+				   g_param_spec_enum ("orientation",
+						      _("Orientation"),
+						      _("The orientation of the tray."),
+						      GTK_TYPE_ORIENTATION,
+						      GTK_ORIENTATION_HORIZONTAL,
+						      G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
   
   manager_signals[TRAY_ICON_ADDED] =
     g_signal_new ("tray_icon_added",
@@ -155,6 +207,13 @@ egg_tray_manager_class_init (EggTrayManagerClass *klass)
 		  g_cclosure_marshal_VOID__VOID,
 		  G_TYPE_NONE, 0);
 
+#if defined (GDK_WINDOWING_X11)
+  /* Nothing */
+#elif defined (GDK_WINDOWING_WIN32)
+  g_warning ("Port eggtraymanager to Win32");
+#else
+  g_warning ("Port eggtraymanager to this GTK+ backend");
+#endif
 }
 
 static void
@@ -169,6 +228,44 @@ egg_tray_manager_finalize (GObject *object)
   G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
+static void
+egg_tray_manager_set_property (GObject      *object,
+			       guint         prop_id,
+			       const GValue *value,
+			       GParamSpec   *pspec)
+{
+  EggTrayManager *manager = EGG_TRAY_MANAGER (object);
+
+  switch (prop_id)
+    {
+    case PROP_ORIENTATION:
+      egg_tray_manager_set_orientation (manager, g_value_get_enum (value));
+      break;
+    default:
+      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+      break;
+    }
+}
+
+static void
+egg_tray_manager_get_property (GObject    *object,
+			       guint       prop_id,
+			       GValue     *value,
+			       GParamSpec *pspec)
+{
+  EggTrayManager *manager = EGG_TRAY_MANAGER (object);
+
+  switch (prop_id)
+    {
+    case PROP_ORIENTATION:
+      g_value_set_enum (value, manager->orientation);
+      break;
+    default:
+      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+      break;
+    }
+}
+
 EggTrayManager *
 egg_tray_manager_new (void)
 {
@@ -179,6 +276,8 @@ egg_tray_manager_new (void)
   return manager;
 }
 
+#ifdef GDK_WINDOWING_X11
+
 static gboolean
 egg_tray_manager_plug_removed (GtkSocket       *socket,
 			       EggTrayManager  *manager)
@@ -383,28 +482,33 @@ egg_tray_manager_window_filter (GdkXEvent *xev, GdkEvent *event, gpointer data)
       g_signal_emit (manager, manager_signals[LOST_SELECTION], 0);
       egg_tray_manager_unmanage (manager);
     }
-  
   return GDK_FILTER_CONTINUE;
 }
 
+#endif  
+
 static void
 egg_tray_manager_unmanage (EggTrayManager *manager)
 {
+#ifdef GDK_WINDOWING_X11
   Display *display;
   guint32 timestamp;
   GtkWidget *invisible;
 
   if (manager->invisible == NULL)
-	  return;
+    return;
 
   invisible = manager->invisible;
+  g_assert (GTK_IS_INVISIBLE (invisible));
+  g_assert (GTK_WIDGET_REALIZED (invisible));
+  g_assert (GDK_IS_WINDOW (invisible->window));
   
-  display = GDK_WINDOW_XDISPLAY (manager->invisible);
+  display = GDK_WINDOW_XDISPLAY (invisible->window);
   
   if (XGetSelectionOwner (display, manager->selection_atom) ==
-      GDK_WINDOW_XWINDOW (manager->invisible->window))
+      GDK_WINDOW_XWINDOW (invisible->window))
     {
-      timestamp = gdk_x11_get_server_time (manager->invisible->window);      
+      timestamp = gdk_x11_get_server_time (invisible->window);      
       XSetSelectionOwner (display, manager->selection_atom, None, timestamp);
     }
 
@@ -412,8 +516,36 @@ egg_tray_manager_unmanage (EggTrayManager *manager)
 
   manager->invisible = NULL; /* prior to destroy for reentrancy paranoia */
   gtk_widget_destroy (invisible);
+  g_object_unref (G_OBJECT (invisible));
+#endif
 }
 
+static void
+egg_tray_manager_set_orientation_property (EggTrayManager *manager)
+{
+#ifdef GDK_WINDOWING_X11
+  gulong data[1];
+
+  if (!manager->invisible || !manager->invisible->window)
+    return;
+
+  g_assert (manager->orientation_atom != None);
+
+  data[0] = manager->orientation == GTK_ORIENTATION_HORIZONTAL ?
+		SYSTEM_TRAY_ORIENTATION_HORZ :
+		SYSTEM_TRAY_ORIENTATION_VERT;
+
+  XChangeProperty (GDK_WINDOW_XDISPLAY (manager->invisible->window),
+		   GDK_WINDOW_XWINDOW (manager->invisible->window),
+		   manager->orientation_atom,
+		   XA_CARDINAL, 32,
+		   PropModeReplace,
+		   (guchar *) &data, 1);
+#endif
+}
+
+#ifdef GDK_WINDOWING_X11
+
 static gboolean
 egg_tray_manager_manage_xscreen (EggTrayManager *manager, Screen *xscreen)
 {
@@ -436,6 +568,7 @@ egg_tray_manager_manage_xscreen (EggTrayManager *manager, Screen *xscreen)
 				   XScreenNumberOfScreen (xscreen));
   
   invisible = gtk_invisible_new_for_screen (screen);
+  gtk_widget_realize (invisible);
   
   gtk_widget_add_events (invisible, GDK_PROPERTY_CHANGE_MASK | GDK_STRUCTURE_MASK);
 
@@ -444,6 +577,11 @@ egg_tray_manager_manage_xscreen (EggTrayManager *manager, Screen *xscreen)
   manager->selection_atom = XInternAtom (DisplayOfScreen (xscreen), selection_atom_name, False);
 
   g_free (selection_atom_name);
+
+  manager->orientation_atom = XInternAtom (DisplayOfScreen (xscreen),
+					   "_NET_SYSTEM_TRAY_ORIENTATION",
+					   FALSE);
+  egg_tray_manager_set_orientation_property (manager);
   
   timestamp = gdk_x11_get_server_time (invisible->window);
   XSetSelectionOwner (DisplayOfScreen (xscreen), manager->selection_atom,
@@ -471,7 +609,8 @@ egg_tray_manager_manage_xscreen (EggTrayManager *manager, Screen *xscreen)
 		  False, StructureNotifyMask, (XEvent *)&xev);
 
       manager->invisible = invisible;
-
+      g_object_ref (G_OBJECT (manager->invisible));
+      
       manager->opcode_atom = XInternAtom (DisplayOfScreen (xscreen),
 					  "_NET_SYSTEM_TRAY_OPCODE",
 					  False);
@@ -492,6 +631,8 @@ egg_tray_manager_manage_xscreen (EggTrayManager *manager, Screen *xscreen)
     }
 }
 
+#endif
+
 gboolean
 egg_tray_manager_manage_screen (EggTrayManager *manager,
 				GdkScreen      *screen)
@@ -499,16 +640,15 @@ egg_tray_manager_manage_screen (EggTrayManager *manager,
   g_return_val_if_fail (GDK_IS_SCREEN (screen), FALSE);
   g_return_val_if_fail (manager->screen == NULL, FALSE);
 
+#ifdef GDK_WINDOWING_X11
   return egg_tray_manager_manage_xscreen (manager, 
 					  GDK_SCREEN_XSCREEN (screen));
+#else
+  return FALSE;
+#endif
 }
 
-gboolean
-egg_tray_manager_manage (EggTrayManager *manager)
-{
-  return egg_tray_manager_manage_xscreen (manager, 
-					  DefaultScreenOfDisplay (gdk_display));
-}
+#ifdef GDK_WINDOWING_X11
 
 static gboolean
 egg_tray_manager_check_running_xscreen (Screen *xscreen)
@@ -527,30 +667,29 @@ egg_tray_manager_check_running_xscreen (Screen *xscreen)
     return FALSE;
 }
 
-#if HAVE_GTK_MULTIHEAD
+#endif
+
 gboolean
 egg_tray_manager_check_running (GdkScreen *screen)
 {
   g_return_val_if_fail (GDK_IS_SCREEN (screen), FALSE);
 
-  return egg_tray_manager_check_running_xscreen (GDK_SCREEN_XSCREEN (xscreen));
-}
+#ifdef GDK_WINDOWING_X11
+  return egg_tray_manager_check_running_xscreen (GDK_SCREEN_XSCREEN (screen));
+#else
+  return FALSE;
 #endif
-
-gboolean
-egg_tray_manager_check_running_default_screen (void)
-{
-  return egg_tray_manager_check_running_xscreen (DefaultScreenOfDisplay (gdk_display));
 }
 
 char *
 egg_tray_manager_get_child_title (EggTrayManager *manager,
 				  EggTrayManagerChild *child)
 {
+  char *retval = NULL;
+#ifdef GDK_WINDOWING_X11
   Window *child_window;
   Atom utf8_string, atom, type;
   int result;
-  char *retval;
   int format;
   gulong nitems;
   gulong bytes_after;
@@ -596,7 +735,30 @@ egg_tray_manager_get_child_title (EggTrayManager *manager,
   retval = g_strndup (val, nitems);
 
   XFree (val);
-
+#endif
   return retval;
+}
 
+void
+egg_tray_manager_set_orientation (EggTrayManager *manager,
+				  GtkOrientation  orientation)
+{
+  g_return_if_fail (EGG_IS_TRAY_MANAGER (manager));
+
+  if (manager->orientation != orientation)
+    {
+      manager->orientation = orientation;
+
+      egg_tray_manager_set_orientation_property (manager);
+
+      g_object_notify (G_OBJECT (manager), "orientation");
+    }
+}
+
+GtkOrientation
+egg_tray_manager_get_orientation (EggTrayManager *manager)
+{
+  g_return_val_if_fail (EGG_IS_TRAY_MANAGER (manager), GTK_ORIENTATION_HORIZONTAL);
+
+  return manager->orientation;
 }
