@@ -44,7 +44,8 @@ static GConfEnumStringPair panel_orient_map [] = {
 	{ PANEL_ORIENT_UP,    "panel-orient-up" },
 	{ PANEL_ORIENT_DOWN,  "panel-orient-down" },
 	{ PANEL_ORIENT_LEFT,  "panel-orient-left" },
-	{ PANEL_ORIENT_RIGHT, "panel-orient-right" }
+	{ PANEL_ORIENT_RIGHT, "panel-orient-right" },
+	{ 0,                  NULL }
 };
 
 static gboolean
@@ -69,6 +70,7 @@ panel_compatibility_map_orient_string (const char  *str,
 static GConfEnumStringPair panel_orientation_map [] = {
 	{ GTK_ORIENTATION_HORIZONTAL, "panel-orientation-horizontal" },
 	{ GTK_ORIENTATION_VERTICAL,   "panel-orientation-vertical" },
+	{ 0,                          NULL }
 };
 
 
@@ -103,6 +105,7 @@ static GConfEnumStringPair panel_edge_map [] = {
 	{ BORDER_RIGHT,  "panel-edge-right" },
 	{ BORDER_BOTTOM, "panel-edge-bottom" },
 	{ BORDER_LEFT,   "panel-edge-left" },
+	{ 0,             NULL }
 };
 
 static gboolean
@@ -140,6 +143,7 @@ static GConfEnumStringPair panel_type_map [] = {
 	{ SLIDING_PANEL,   "sliding-panel" },
 	{ FLOATING_PANEL,  "floating-panel" },
 	{ MENU_PANEL,      "menu-panel" },
+	{ 0,               NULL }
 };
 
 static gboolean
@@ -169,6 +173,7 @@ static GConfEnumStringPair panel_size_map [] = {
 	{ PANEL_SIZE_LARGE,    "panel-size-large" },
 	{ PANEL_SIZE_X_LARGE,  "panel-size-x-large" },
 	{ PANEL_SIZE_XX_LARGE, "panel-size-xx-large" },
+	{ 0,                   NULL }
 };
 
 static gboolean
@@ -194,6 +199,7 @@ static GConfEnumStringPair panel_background_type_map [] = {
 	{ PANEL_BACK_NONE,   "no-background" },
 	{ PANEL_BACK_COLOR,  "color-background" },
 	{ PANEL_BACK_IMAGE,  "pixmap-background" },
+	{ 0,                 NULL }
 };
 
 static gboolean
@@ -1007,20 +1013,20 @@ panel_compatibility_maybe_copy_old_config (GConfClient *client)
 		return;
 
 	if (!(engine = get_homedir_source ()))
-		goto set_migrated_flag;
+		goto no_migration_needed;;
 
 	if (!is_general_key_set (engine, PANEL_OLD_CONFIG_DIR, "panel_id_list")    &&
 	    !is_general_key_set (engine, PANEL_OLD_CONFIG_DIR, "toplevel_id_list") &&
 	    !is_general_key_set (engine, PANEL_OLD_CONFIG_DIR, "applet_id_list")   &&
 	    !is_general_key_set (engine, PANEL_OLD_CONFIG_DIR, "object_id_list"))
-		goto set_migrated_flag;
+		goto no_migration_needed;
 
 	copy_gconf_dir (client, PANEL_OLD_CONFIG_DIR, PANEL_CONFIG_DIR);
 
- set_migrated_flag:
 	key = panel_gconf_general_key ("profiles_migrated");
 	gconf_client_set_bool (client, key, TRUE, NULL);
 
+ no_migration_needed:
 	if (engine)
 		gconf_engine_unref (engine);
 }
