@@ -406,6 +406,7 @@ panel_properties_dialog_setup_image_chooser (PanelPropertiesDialog *dialog,
 	GtkFileFilter *filter;
 	char          *image;
 
+	//TODO add a preview widget
 	dialog->image_chooser = glade_xml_get_widget (gui, "image_chooser");
 
 	filter = gtk_file_filter_new ();
@@ -949,8 +950,6 @@ panel_properties_dialog_new (PanelToplevel *toplevel,
 						     panel_toplevel_get_is_attached (dialog->toplevel));
 
 	panel_toplevel_push_autohide_disabler (dialog->toplevel);
-	panel_widget_register_open_dialog (panel_toplevel_get_panel_widget (dialog->toplevel),
-					   dialog->properties_dialog);
 
 	gtk_widget_show (dialog->properties_dialog);
 
